# `@salesforce-ux/c360-input-checkbox`
[![npm (custom registry)](https://img.shields.io/npm/v/@salesforce-ux/c360-input-checkbox/latest?color=green&label=npm%20package)](https://www.npmjs.com/package/@salesforce-ux/c360-input-checkbox)
## About

A checkable input that communicates if an option is true, false or indeterminate.

## Getting Started

Let's start by installing `c360-input-checkbox` as a dependency of your project with [npm](https://www.npmjs.com/package/@salesforce-ux/c360-input-checkbox).

```
npm i @salesforce-ux/c360-input-checkbox
```

## Distributable
After installation, all the distributables for the `c360-input-checkbox` are found under `/node_modules/@salesforce-ux/c360-input-checkbox/dist/` folder.

|File Name |Description |
|- |- |
|`input-checkbox.css` |The CSS file specific to `c360-input-checkbox` only. It doesnot include the styles for it's parent `sds-input-checkbox`. `c360-input-checkbox` extends from `sds-input-checkbox`|
|`input-checkbox.compiled.css` |The Compiled CSS file for `c360-input-checkbox`. This file includes styles for both `c360-input-checkbox` and its parent `sds-input-checkbox`. This file is useful for **LWC** applications.([see below](#for-lightning-web-componentlwc-application) &rarr;)|
|`input-checkbox.js` |The bundled JS file for `c360-input-checkbox` component. This file is useful for **Non LWC** applications.([see below](#for-non-lwc-application) &rarr;)|


## `c360-input-checkbox` Integration

For the sake of understanding, we will categorize the development environment into LWC and Non LWC application.    
This Guide will cover the integration approach for these two types of application.

### For `Lightning Web Component(LWC)` Application

> #### Dependency Inclusion

[`c360-styling-hooks`](https://www.npmjs.com/package/@salesforce-ux/c360-styling-hooks) is a styling dependency for `c360-input-checkbox`. Hence, this needs to be embedded into your web app in order to make the `c360-input-checkbox` render properly.

```css
/* myComponent.css */
@import "@salesforce-ux/c360-styling-hooks/dist/hooks.custom-props.css";
```

There are also other ways [`c360-styling-hooks`](https://www.npmjs.com/package/@salesforce-ux/c360-styling-hooks) can be embedded. Please checkout the [`c360-styling-hooks` Integration Guide](https://www.npmjs.com/package/@salesforce-ux/c360-styling-hooks) to learn more.


> #### Component CSS Import
```css
/* myComponent.css */
@import "@salesforce-ux/c360-styling-hooks/dist/hooks.custom-props.css";
@import '@salesforce-ux/c360-input-checkbox/dist/input-checkbox.compiled.css'
```

> #### HTML Decoration
After that,the HTML of your LWC component template needs to be decorated to have all the named part attributes as per the [component's specification](./input-checkbox.spec.md).
Below is a reference to the component's structure.
```html
<div part="input-checkbox">
  <input type="checkbox" id="checkbox-id" part="checkbox" />
  <div part="indicator">
    <slot name="indicator">
      <sds-icon></sds-icon>
    </slot>
  </div>
  <label part="label" for="checkbox-id">
    <slot></slot>
  </label>
</div>

```

### For `Non LWC` Application


> #### Dependency Inclusion [Read the section above](#dependency-inclusion)


> #### Component Import
```JS
/* myComponent.js */
import C360InputCheckbox from '@salesforce-ux/c360-input-checkbox/dist/input-checkbox';
```

> #### Component Registration
```JS
/* myComponent.js */
customElements.define('c360-input-checkbox', C360InputCheckbox);
```

#### Example

Below is one approach to integrate your `c360-input-checkbox` component.
##### Script
```Js
/* myComponent.js */
import '@salesforce-ux/c360-styling-hooks/dist/hooks.custom-props.css';
import C360InputCheckbox from '@salesforce-ux/c360-input-checkbox/dist/input-checkbox';
window.customElements.define('c360-input-checkbox', C360InputCheckbox);

```

##### HTML
```html
<c360-input-checkbox>Checkbox</c360-input-checkbox>
```

## Interactive Demo
To see more examples with interactive demo, please visit `c360 Subsytem`'s [Storybook Environment](https://c360-subsystem-storybook.herokuapp.com/?path=/story/c360-subsystem-components-input-checkbox--base)
