/* eslint-env jest */
import C360InputCheckbox from '../input-checkbox';
import * as utils from '../../../../../.jest/utils';
customElements.define('c360-input-checkbox', C360InputCheckbox);

describe('c360-input-checkbox', () => {
  afterEach(() => {
    // The jsdom instance is shared across test cases in a single file so reset the DOM
    while (document.body.firstChild) {
      document.body.removeChild(document.body.firstChild);
    }
  });

  it('should contain size attribute by default', async () => {
    const element = utils.renderIntoBody(`<c360-input-checkbox>Checkbox label
      </c360-input-checkbox>`);
    expect(element).toHaveAttribute('size', 'default');
  });

  it('should contain checked attribute and icon', async () => {
    const element = utils.renderIntoBody(`<c360-input-checkbox checked>Checkbox label
      </c360-input-checkbox>`);
    const icon = element.shadowRoot.querySelector('sds-icon');
    expect(element).toHaveAttribute('checked');
    expect(icon).toHaveAttribute('symbol', 'check');
  });

  it('should contain disabled attribute', async () => {
    const element = utils.renderIntoBody(`<c360-input-checkbox disabled>Checkbox label
      </c360-input-checkbox>`);
    expect(element).toHaveAttribute('disabled');
  });

  it('should contain checked & disabled attributes', async () => {
    const element = utils.renderIntoBody(`<c360-input-checkbox checked disabled>Checkbox label
      </c360-input-checkbox>`);
    expect(element).toHaveAttribute('checked');
    expect(element).toHaveAttribute('disabled');
  });

  it('should contain indeterminate attribute', async () => {
    const element = utils.renderIntoBody(`<c360-input-checkbox indeterminate>
        Checkbox label
      </c360-input-checkbox>`);
    const icon = element.shadowRoot.querySelector('sds-icon');
    expect(element).toHaveAttribute('indeterminate');
    expect(icon).toHaveAttribute('symbol', 'dash');
  });

  it('should contain required & error attributes', async () => {
    const element = utils.renderIntoBody(`<c360-input-checkbox required error>
        Checkbox label
        <span slot="help-text">Validation Message</span>
      </c360-input-checkbox>`);
    expect(element).toHaveAttribute('required');
    expect(element).toHaveAttribute('error');
  });

  it('should contain help-text slot', async () => {
    const element = utils.renderIntoBody(`<c360-input-checkbox>Checkbox</c360-input-checkbox>`);
    const helpTextSlot = element.shadowRoot.querySelector('slot[name="help-text"]');
    expect(helpTextSlot).toBeInTheDocument();
  });

  it('is accessible', async () => {
    const element = utils.renderIntoBody(`<c360-input-checkbox>
      Checkbox label
    </c360-input-checkbox>`);
    return Promise.resolve().then(() => {
      expect(element).toBeAccessible();
    });
  });
});
