# Input Checkbox

## Overview

A checkable input that communicates if an option is true, false or indeterminate.

## Use Cases

[SDS Input Checkbox Use Cases &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/input-checkbox/input-checkbox.spec.md#use-cases)

## Non-goals

[SDS Input Checkbox Non Goals &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/input-checkbox/input-checkbox.spec.md#non-goals)


## Features

[SDS Input Checkbox Features &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/input-checkbox/input-checkbox.spec.md#features)

## Prior Art/Examples

[SDS Input Checkbox Prior Art/Examples &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/input-checkbox/input-checkbox.spec.md#prior-artexamples)

## API

The checkbox component should support all attributes, functionality, and accessibility considerations of the HTML Input Checkbox State.

## Custom Element
This specification will apply to a C360 subsystem ecosystem:

`c360-input-checkbox` - This is owned by the Customer 360 (C360) Team.

## Anatomy and Appearance

[SDS Input Checkbox Anatomy and Appearance &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/input-checkbox/input-checkbox.spec.md#anatomy-and-appearance)

### DOM Structure

```html
<host>
  <div part="input-checkbox">
    <input type="checkbox" id="checkbox-id" part="checkbox" />
    <div part="indicator">
      <slot name="indicator">
      </slot>
    </div>
    <label part="label" for="checkbox-id">
      <slot></slot>
    </label>
  </div>
  <slot name="help-text"></slot>
</host>
```

### Slots

| Slot Name   | Description                                                                            | Fallback Content |
| ----------- | -------------------------------------------------------------------------------------- | ---------------- |
| `label`     | The text content that describes the purpose of the checkbox                            | empty            |
| `indicator` | Content to indicate the control's checked and intermediate states (most often an icon) | empty            |
| `help-text`     | Content area for additional text, such as examples of the type of required data entry, or error messages                              | empty     |
| `default`     | An optional space to provide your own checkbox indicator.                              | `<sds-icon>`     |



### Parts

[SDS Input Checkbox Parts &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/input-checkbox/input-checkbox.spec.md#parts)

### Properties & Attributes

| Attribute       | Type     | Default Value | Description                                                                                            |
| --------------- | -------- | ------------- | ------------------------------------------------------------------------------------------------------ |
| `checked`       | `bool`   | `false`       | If present, the checkbox is toggled on by default                                                      |
| `indeterminate` | `bool`   | `false`       | If present, the checkbox is in indeterminate state rather than `true` or `false`                       |
| `value`         | `string` | `'on'`        | The string to use as the value of the checkbox when submitting the form, if the checkbox is toggled on |
| `disabled`      | `bool`   | `false`       | Prevents the user from interacting with the control                                                    |
| `required`      | `bool`   | `false`       | Indicates that the control is invalid unless checked                                                   |
| `name`          | `string` | `null`        | Specifies the name of the control for purposes of form submission                                      |
| `id`            | `string` | `null`        | The ID of the input and the value of the label's `for` attribute                                       |
| `error`         | `bool`   | `null`        | Indicates the checkbox is in an error state                                                            |
| `size`         | `default/medium/small`   | `default`        | Determines the size of the checkbox                                                            |


### Events

| Event Name   | Type   | Bubbles | Composed | Cancellable | Dispatch Behavior                                                |
| ------------ | ------ | ------- | -------- | ----------- | ---------------------------------------------------------------- |
| `c360-change` | custom | `true`  | `true`   | `false`     | When the element is `:checked` by clicking or using the keyboard |
| `c360-focus`  | custom | `true`  | `true`   | `false`     | When the element receives focus                                  |
| `c360-blur`   | custom | `true`  | `true`   | `false`     | When the element loses focus                                     |


### Styling Hooks

N/A. Currently there is no customization through styling hooks is being offered for the `c360-input-checkbox`.

## Behavior

### States & Interactions

[SDS Input Checkbox States & Interaction &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/input-checkbox/input-checkbox.spec.md#states--interactions)


## Accessibility

[SDS Input Checkbox Accessibility &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/input-checkbox/input-checkbox.spec.md#accessibility)


## Internationalization

[SDS Input Checkbox Internationalization &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/input-checkbox/input-checkbox.spec.md#internationalization)

## Test Plan

[SDS Input Checkbox Test Plan &rarr;](https://github.com/salesforce-ux/salesforce-design-system/blob/main/packages/sds-components/src/input-checkbox/input-checkbox.spec.md#test-plan)
