/* Copyright (c) 2015-present, salesforce.com, inc. All rights reserved
  Licensed under BSD 3-Clause - see LICENSE.txt or git.io/sfdc-license */

import InputCheckbox from './input-checkbox';
import InputCheckboxDocs from './input-checkbox.mdx';

export default {
  title: 'C360 Subsystem/Components/Input Checkbox',
  component: InputCheckbox,
  parameters: {
    docs: {
      page: InputCheckboxDocs,
    },
    specs: {
      disabled: true,
    },
  },
  argTypes: {
    default: {
      control: {
        type: 'text',
      },
      defaultValue: 'Checkbox label',
      table: {
        category: 'slots',
      },
    },
    size: {
      control: { type: 'select', options: ['small', 'medium', 'default'] },
      defaultValue: 'default',
      table: {
        category: 'attributes',
      },
    },
  },
};

const BaseTemplate = (args) => `
  <c360-input-checkbox
    size=${args.size || 'default'}
    ${args.checked ? 'checked' : ''}
    ${args.disabled ? 'disabled' : ''}>
    ${args.default}
  </c360-input-checkbox>
`;
export const Base = BaseTemplate.bind({});
Base.argTypes = {
  checked: {
    control: {
      type: 'boolean',
    },
    defaultValue: '',
    table: {
      category: 'attributes',
    },
  },
  disabled: {
    control: {
      type: 'boolean',
    },
    defaultValue: false,
    table: {
      category: 'attributes',
    },
  },
};

const ErrorRequiredTemplate = (args) => `
  <c360-input-checkbox
    size=${args.size || 'default'}
    ${args.required ? 'required' : ''}
    ${args.error ? 'error' : ''}>
    ${args.default}
    <span slot="help-text">${args.helpText || ''}</span>
  </c360-input-checkbox>
`;
export const ErrorAndRequired = ErrorRequiredTemplate.bind({});
ErrorAndRequired.argTypes = {
  required: {
    control: {
      type: 'boolean',
    },
    defaultValue: false,
    table: {
      category: 'attributes',
    },
  },
  error: {
    control: {
      type: 'boolean',
    },
    defaultValue: true,
    table: {
      category: 'attributes',
    },
  },
  helpText: {
    control: {
      type: 'text',
    },
    defaultValue: '',
    table: {
      category: 'slots',
    },
  },
};

const IndeterminateTemplate = (args) => `
  <c360-input-checkbox
    size=${args.size || 'default'}
    ${args.indeterminate ? 'indeterminate' : ''}>
    ${args.default}
  </c360-input-checkbox>
`;
export const Indeterminate = IndeterminateTemplate.bind({});
Indeterminate.args = {
  indeterminate: 'indeterminate',
};
Indeterminate.argTypes = {
  indeterminate: {
    control: {
      type: 'boolean',
    },
    defaultValue: false,
    table: {
      category: 'attributes',
    },
  },
};

const EventsTemplate = () => `
  <c360-input-checkbox>
    Checkbox label
  </c360-input-checkbox>
  <div id="output"></div>
  <script>
    var inputCheckbox360 = document.querySelector("c360-input-checkbox");
    inputCheckbox360.addEventListener('c360-change', event => {
      const para = document.createElement("p");
      para.innerHTML = '<span>Checkbox Change triggered</span>';
      document.querySelector('#output').appendChild(para);
    });
  </script>
`;
export const ChangeEvent = EventsTemplate.bind({});
